==> alg-common-1.19.5-20190819.084959-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/ActivityModel.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

public class ActivityModel {
    long activityId;
    long slotId;
    long appId;
    long activityType; //活动类型 **new**
    double alpha = 1.5; //模型参数
    double beta = 2; // 模型参数
    double reward = 0; //模型参数
    double count = 0; //模型参数
    double changeScore = 0;//模型参数
    long updateTime = 0;//修改时间

    //3.5版本新加参数
    int ifOldActivity=0; //是否老活动，1：是；0：不是
    long TurnOldAcrtivityTime = 0;//成为老活动时间

    boolean isHot = false; //热点活动， true：热点活动，false：普通活动
    long uploadTime = 0; //活动上架时间，微秒

    int subType = 0; //v4.0 皮肤含有ops或vm新活动 1;否则老活动 0

    public int getIfOldActivity() {
        return ifOldActivity;
    }

    public void setIfOldActivity(int ifOldActivity) {
        this.ifOldActivity = ifOldActivity;
    }

    public long getTurnOldAcrtivityTime() {
        return TurnOldAcrtivityTime;
    }

    public void setTurnOldAcrtivityTime(long turnOldAcrtivityTime) {
        TurnOldAcrtivityTime = turnOldAcrtivityTime;
    }



    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }


    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public double getAlpha() {
        return alpha;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public double getBeta() {
        return beta;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public double getCount() {
        return count;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public long getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(long updateTime) {
        this.updateTime = updateTime;
    }

    public boolean isHot() {
        return isHot;
    }

    public void setHot(boolean hot) {
        isHot = hot;
    }

    public long getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(long uploadTime) {
        this.uploadTime = uploadTime;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    @Override
    public String toString() {
        return "ActivityModel{" +
                "activityId=" + activityId +
                ", slotId=" + slotId +
                ", appId=" + appId +
                ", activityType=" + activityType +
                ", alpha=" + alpha +
                ", beta=" + beta +
                ", reward=" + reward +
                ", count=" + count +
                ", changeScore=" + changeScore +
                ", updateTime=" + updateTime +
                ", ifOldActivity=" + ifOldActivity +
                ", TurnOldAcrtivityTime=" + TurnOldAcrtivityTime +
                ", isHot=" + isHot +
                ", uploadTime=" + uploadTime +
                ", subType=" + subType +
                '}';
    }
}

==> alg-common-1.19.7-20190827.095037-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/ActivityModel.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

public class ActivityModel {
    long activityId;
    long slotId;
    long appId;
    long activityType; //活动类型 **new**
    double alpha = 1.5; //模型参数
    double beta = 2; // 模型参数
    double reward = 0; //模型参数
    double count = 0; //模型参数
    double changeScore = 0;//模型参数
    long updateTime = 0;//修改时间

    //3.5版本新加参数
    int ifOldActivity=0; //是否老活动，1：是；0：不是
    long TurnOldAcrtivityTime = 0;//成为老活动时间

    boolean isHot = false; //热点活动， true：热点活动，false：普通活动
    long uploadTime = 0; //活动上架时间，微秒

    int subType = 0; //v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
    boolean isExcellent; //v4.0 是否是优质活动
    double nPvClick; //v4.0 归一化每pv券点击
    double nPvCost; //v4.0 归一化每pv消耗
    double score; //4.0 归一化得分

    public int getIfOldActivity() {
        return ifOldActivity;
    }

    public void setIfOldActivity(int ifOldActivity) {
        this.ifOldActivity = ifOldActivity;
    }

    public long getTurnOldAcrtivityTime() {
        return TurnOldAcrtivityTime;
    }

    public void setTurnOldAcrtivityTime(long turnOldAcrtivityTime) {
        TurnOldAcrtivityTime = turnOldAcrtivityTime;
    }



    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }


    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public double getAlpha() {
        return alpha;
    }

    public void setAlpha(double alpha) {
        this.alpha = alpha;
    }

    public double getBeta() {
        return beta;
    }

    public void setBeta(double beta) {
        this.beta = beta;
    }

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public double getCount() {
        return count;
    }

    public void setCount(double count) {
        this.count = count;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public long getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(long updateTime) {
        this.updateTime = updateTime;
    }

    public boolean isHot() {
        return isHot;
    }

    public void setHot(boolean hot) {
        isHot = hot;
    }

    public long getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(long uploadTime) {
        this.uploadTime = uploadTime;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public boolean isExcellent() {
        return isExcellent;
    }

    public void setExcellent(boolean excellent) {
        isExcellent = excellent;
    }

    public double getnPvClick() {
        return nPvClick;
    }

    public void setnPvClick(double nPvClick) {
        this.nPvClick = nPvClick;
    }

    public double getnPvCost() {
        return nPvCost;
    }

    public void setnPvCost(double nPvCost) {
        this.nPvCost = nPvCost;
    }

    public double getScore() {
        return score;
    }

    public void setScore(double score) {
        this.score = score;
    }

    @Override
    public String toString() {
        return "ActivityModel{" +
                "activityId=" + activityId +
                ", slotId=" + slotId +
                ", appId=" + appId +
                ", activityType=" + activityType +
                ", alpha=" + alpha +
                ", beta=" + beta +
                ", reward=" + reward +
                ", count=" + count +
                ", changeScore=" + changeScore +
                ", updateTime=" + updateTime +
                ", ifOldActivity=" + ifOldActivity +
                ", TurnOldAcrtivityTime=" + TurnOldAcrtivityTime +
                ", isHot=" + isHot +
                ", uploadTime=" + uploadTime +
                ", subType=" + subType +
                ", isExcellent=" + isExcellent +
                ", nPvClick=" + nPvClick +
                ", nPvCost=" + nPvCost +
                ", score=" + score +
                '}';
    }
}
